@@ -563,7 +563,6 @@ SPDConnection *spd_open2(const char *client_name, const char *connection_name,
 			*error_result = strdup("Thread initialization failed");
 			SPD_DBG(*error_result);
 			fclose(connection->stream);
-			close(connection->socket);
 			free(connection);
 			connection = NULL;
 			goto out;
@@ -863,7 +862,10 @@ spd_char(SPDConnection * connection, SPDPriority priority,
 	if (ret)
 		RET(-1);
 
-	sprintf(command, "CHAR %s", character);
+	if (!strcmp(character, " "))
+		sprintf(command, "CHAR space");
+	else
+		sprintf(command, "CHAR %s", character);
 	ret = spd_execute_command_wo_mutex(connection, command);
 	if (ret)
 		RET(-1);
